@@ -18,6 +18,14 @@ class SurveyListView(ContextTitleMixin, ListView):
     title_page = 'Survey List'
     paginate_by = 12
 
+    def get_queryset(self):
+        query = self.request.GET.get('q')
+        if query:
+            object_list = self.model.objects.filter(name__icontains=query)
+        else:
+            object_list = self.model.objects.all()
+        return object_list
+
 
 @method_decorator(login_required, name='dispatch')
 class SurveyFormView(FormMixin, DetailView):
